Module: Honeybadger::Breadcrumbs::BroadcastLogWrapper Private

Includes:
LogHelper
Defined in:
lib/honeybadger/breadcrumbs/logging.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

ActiveSupport::BroadcastLogger forwards one logical log event to multiple Logger instances. Wrapping it separately records the event once while silencing the sink loggers for the duration of the broadcast.

Constant Summary collapse

LOG_METHOD_SEVERITIES =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

{
  debug: ::Logger::DEBUG,
  info: ::Logger::INFO,
  warn: ::Logger::WARN,
  error: ::Logger::ERROR,
  fatal: ::Logger::FATAL,
  unknown: ::Logger::UNKNOWN
}.freeze

Constants included from LogHelper

LogHelper::LOG_SEVERITY_LABELS

Instance Method Summary collapse

Instance Method Details

#add(severity, message = nil, progname = nil, &block) ⇒ Object Also known as: log

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



80
81
82
83
# File 'lib/honeybadger/breadcrumbs/logging.rb', line 80

def add(severity, message = nil, progname = nil, &block)
  add_log_breadcrumb(severity, message, progname)
  without_sink_breadcrumbs { super(severity, message, progname, &block) }
end